@@ -1,11 +1,14 @@
 __all__ = ['EntryModel', 'Empty']
 
 from torch import nn
+from tai_chi_engine.stateful import Stateful
+
+
 class EntryModel(nn.Module):
     is_entry = True
     
     @classmethod
-    def from_quantify(cls, ):
+    def from_quantify(cls, quantify):
         raise ImportError(
             f"Please define class function 'from_quantify' for {cls.__name__}"
         )
@@ -21,4 +24,5 @@ class Empty(EntryModel):
     @classmethod
     def from_quantify(cls,
         quantify):
-        return cls()
\ No newline at end of file
+        return cls()
+
